#
# spec file for package gtkpod
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           gtkpod
Summary:        A platform independent GUI for the Apple iPod
License:        GPL-2.0-or-later
Group:          Productivity/Multimedia/Sound/Utilities
Version:        2.1.5
Release:        8.1
URL:            http://gtkpod.sourceforge.net/
Source0:        http://downloads.sourceforge.net/project/gtkpod/gtkpod/gtkpod-2.1.5/%{name}-%{version}.tar.gz
# PATCH-FEATURE-OPENSUSE gtkpod-pref.patch -- Preferences to mountpoint and some tag preferences
Patch0:         gtkpod-pref.patch
# PATCH-FEATURE-UPSTREAM use-python3.patch -- Use python3
Patch1:         use-python3.patch
# PATCH-FIX-UPSTREAM xml-inc.patch -- Add missing include
Patch2:         xml-inc.patch
BuildRequires:  fdupes
BuildRequires:  flex
BuildRequires:  gcc-c++
BuildRequires:  intltool
BuildRequires:  libdiscid-devel
BuildRequires:  libgpod-devel
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(clutter-gtk-1.0) >= 1.2
BuildRequires:  pkgconfig(flac) >= 1.2.1
BuildRequires:  pkgconfig(gstreamer-1.0) >= 1.0
BuildRequires:  pkgconfig(gstreamer-base-1.0) >= 1.0
BuildRequires:  pkgconfig(gstreamer-pbutils-1.0) >= 1.0
BuildRequires:  pkgconfig(gstreamer-plugins-base-1.0) >= 1.0
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(id3tag) >= 0.15
BuildRequires:  pkgconfig(iso-codes)
BuildRequires:  pkgconfig(libanjuta-3.0)
BuildRequires:  pkgconfig(libbrasero-media3) >= 3.0
BuildRequires:  pkgconfig(libcurl) >= 7.10.0
BuildRequires:  pkgconfig(libdiscid) >= 0.2.2
BuildRequires:  pkgconfig(libmusicbrainz5) >= 5.0.1
BuildRequires:  pkgconfig(vorbisfile) >= 1.3.1
%glib2_gsettings_schema_requires

%description
gtkpod is a Platform-Independent GUI for the Apple iPod using GTK2. It
allows you to upload songs and play lists to your iPod. It supports ID3
tag editing with multiple charsets for ID3 tags, detects duplicate
songs, allows offline modification of the database with later
synchronization, and more.

%package devel
Summary:        Development files for gtkpod, a GUI for Apple iPods
Group:          Development/Libraries/C and C++
Requires:       libatomicparsley0 = %{version}
Requires:       libgtkpod1 = %{version}

%description devel
This package contains development headers for libgtkpod

gtkpod is a Platform-Independent GUI for the Apple iPod using GTK2. It
allows you to upload songs and play lists to your iPod. It supports ID3
tag editing with multiple charsets for ID3 tags, detects duplicate
songs, allows offline modification of the database with later
synchronization, and more.

%package -n libgtkpod1
Summary:        A platform independent GUI for the Apple® iPod® - System Library
Group:          System/Libraries

%description -n libgtkpod1
gtkpod is a Platform-Independent GUI for the Apple iPod using GTK2. It
allows you to upload songs and play lists to your iPod. It supports ID3
tag editing with multiple charsets for ID3 tags, detects duplicate
songs, allows offline modification of the database with later
synchronization, and more.

Shared Library, to be installed by package dependencies.

%package -n libatomicparsley0
Summary:        Atomic parsley in gtkpod
Group:          System/Libraries

%description -n libatomicparsley0
This is the core library for atomic parsley of mp4 files in gtkpod.
Library including read/write lyric support for the first time and
write metadata function.

%lang_package

%prep
%autosetup -p1

%build
export CFLAGS="%{optflags} -fcommon"
%configure --disable-static
make V=1

%install
%make_install
find %{buildroot}%{_libdir} -name '*.la' -type f -delete -print
%suse_update_desktop_file %name Utility SyncUtility
%find_lang %{name} %{?no_lang_C}
%fdupes %{buildroot}%{_datadir}

%if 0%{?suse_version} > 1130

%post
%desktop_database_post
%icon_theme_cache_post
%glib2_gsettings_schema_post
%endif

%if 0%{?suse_version} > 1130

%postun
%desktop_database_postun
%icon_theme_cache_postun
%glib2_gsettings_schema_postun
%endif

%post -n libgtkpod1 -p /sbin/ldconfig

%postun -n libgtkpod1 -p /sbin/ldconfig

%post -n libatomicparsley0 -p /sbin/ldconfig

%postun -n libatomicparsley0 -p /sbin/ldconfig

%files
%doc README NEWS INSTALL ChangeLog AUTHORS
%license COPYING
%{_bindir}/gtkpod
%{_datadir}/gtkpod/
%{_datadir}/icons/hicolor/*/*/*.png
%{_datadir}/icons/hicolor/*/*/%{name}.svg
%{_datadir}/applications/gtkpod.desktop
%{_datadir}/glib-2.0/schemas/org.gtkpod.gschema.xml
%{_datadir}/glib-2.0/schemas/org.gtkpod.sjcd.gschema.xml
%{_libdir}/gtkpod/
%{_mandir}/*/%{name}.*

%files -n libgtkpod1
%{_libdir}/libgtkpod.so.*

%files -n libatomicparsley0
%{_libdir}/libatomicparsley.so.*

%files lang -f %{name}.lang

%files devel
%{_includedir}/gtkpod/
%{_libdir}/libatomicparsley.so
%{_libdir}/libgtkpod.so
%{_libdir}/pkgconfig/libgtkpod-1.1.0.pc

%changelog
* Tue Jul  2 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Add xml-inc.patch: Add missing include. Fix build in factory.
- Rebase patches with quilt.
* Thu Feb  8 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Prepare for RPM 4.20: use autosetup.
* Thu Jun  4 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Export -fcommon to optflags, fixes build with gcc 10. Yes this is
  a cheat, but good enough for this more or less abandoned package.
* Wed Mar  4 2020 Antonio Larrosa <alarrosa@suse.com>
- Add patch to port a script to python3:
  * use-python3.patch
- Use %%license
* Thu Jan 30 2020 Dominique Leuenberger <dimstar@opensuse.org>
- No longer recommend -lang: supplements are in use
* Tue Aug 27 2019 Jan Engelhardt <jengelh@inai.de>
- Avoid use of ®/™ signs in specfiles as per guidelines.
- Specfile modernization: remove %%clean, %%defattr and BuildRoot.
* Fri Feb  3 2017 zaitor@opensuse.org
- Drop pkgconfig(webkitgtk-3.0) BuildRequires: No longer depend on
  old inscure webkitgtk3.
* Thu Jun 11 2015 dimstar@opensuse.org
- Update to version 2.1.5:
  + Improvements:
  - Port to GStreamer 1.0.
  - Upgrade sjcd plugin to use latest sound juicer code.
  - Refactor deprecated GtkTable replacing with GtkGrid.
  + Bugsfixes:
  - Fixes the setting display of the repository file settings.
  - Update install instructions and documentation.
- Replace BuildRequires for port to GStreamer 1.0:
  + Drop pkgconfig(gstreamer-0.10), pkgconfig(gstreamer-base-0.10),
    pkgconfig(gstreamer-interfaces-0.10),
    pkgconfig(gstreamer-pbutils-0.10) and
    pkgconfig(gstreamer-plugins-base-0.10).
  + Add pkgconfig(gstreamer-1.0), pkgconfig(gstreamer-base-1.0),
    pkgconfig(gstreamer-plugins-base-1.0) and
    pkgconfig(gstreamer-pbutils-1.0).
- Replace pkgconfig(libmusicbrainz4) BuildRequires with
  pkgconfig(libmusicbrainz5), following upstreams port.
- Add pkgconfig(iso-codes) BuildRequires to detect iso3166 support
  during build.
- Add pkgconfig(libdiscid) BuildRequires: new dependency.
* Sat Sep  7 2013 dimstar@opensuse.org
- Update to version 2.1.4:
  + Bugfixes:
  - Playlist display and coverart display.
  - Fix showing tracks of selected artist on 64-bit systems.
  - Handle attempts to create duplicate-named playlist.
  + Improvements:
  - Update to support anjuta releases up to 3.9.1.
  - Update clutter, glib and gtk deprecations and updates the
    glib minimum version to 2.31 which was released in 2011.
- Drop gtkpod-gdl362.patch: fixed upstream.
- Drop gtkpod-anjuta-3.8.0.patch: fixed upstream.
* Wed May  8 2013 dimstar@opensuse.org
- Replace gtkpod-gdl362.patch with what upstream commited, as
  commit 47a3bc.
- Add gtkpod-anjuta-3.8.0.patch: fix build with anjuta 3.8.0.
* Sun Jan  6 2013 dimstar@opensuse.org
- Update to version 2.1.3:
  + Improvements:
  - Solve the confusing sorting of the track display. Track
    display sort order is only applied if the tm_autostore
    preference has been set. Otherwise sorting of tracks in a
    playlist is completely manual through a set of radio buttons,
    as well as selecting the column names.
  - Reduce number of selection changed callbacks making track
    selection more efficient.
  - Make it easier for the user to retry entering a valid
    playlist name.
  - Fix to cater for changing API in anjuta version 3.5.3+.
  + Bug fixes:
  - Avoid filter tab categories having null values by including a
    default value.
  - Ensure files with an upper case file extension are loaded
    correctly.
  - Selection of bugs identified in atomic parsley library.
  - Fix setting the default width of main window.
  - Do not accept empty names for smart playlists.
  - Fix segfault when using playcount spin buttons.
  - Fix multiple icons appearing when toggling plugins in
    preferences window.
  - Fix m4a track length value calculated in atomic parsely
    library.
  - Fix for potential crashes when deleting all tracks.
  + Updated translations.
- Drop gtkpod-buffer-overflow.patch and gtkpod-anjuta36.patch:
  fixed upstream.
- Drop libtool BuildRequires and call to autogen.sh, as we don't
  carry any patch touching the build system.
* Mon Nov 26 2012 dimstar@opensuse.org
- Add gtkpod-gdl362.patch: Fix build with gdl 3.6.2.
* Sat Oct 13 2012 dimstar@opensuse.org
- Add gtkpod-anjuta36.patch: Adapt to Anjuta 3.6 API change.
- Add ldconfig call to post/postun of libatomicparsley0 subpackage.
* Mon Jun 18 2012 dimstar@opensuse.org
- Update to version 2.1.2:
  + New Features:
  - sjcd plugin, incorporating the sound juicer CD ripper into
    gtkpod
  - external player plugin restoring functionality to play tracks
    through a configured external media player
  - replace dependency on libmp4v2 (incompatible licence) with
    integrated mp4 read/write library based on the atomic parsley
    application (http://atomicparsley.sourceforge.net)
  + Improvement:
  - Reduce time for listing of tracks in track display in big
    repositories
  + Bug fixes:
  - Fix threading issues / deadlocks with music player, filters
    and track display
  - Fix crash when anjuta g_settings schema is not installed
  - Fixes highlighted by clang compiler (thank to Daniel Forsi)
  - Fix for double free when adding music using the 'add folder'
    command.
- Add new BuildRequires following upstreams changes and extensions:
  + pkgconfig()-style: gstreamer-0.10, gstreamer-base-0.10,
    gstreamer-pbutils-0.10, gstreamer-plugins-base-0.10,
    libbrasero-media3, webkitgtk-3.0.
  + gcc-c++, libdiscid-devel
- Replace old style BuildRequires with pkgconfig() style:
  + Old style: curl-devel, flac-devel, libid3tag-devel
  + New style: libcurl, flac, id3tag
- Add subpackage for new shared library libatomicparsley0.
- Add gtkpod-buffer-overflow.patch: Fix bufferoverflow reported by
  brp-check-suse.
* Mon Jan  9 2012 dimstar@opensuse.org
- Update to version 2.1.1:
  + New Features:
  - Clarity plugin for alternative display of coverart using
    clutter/opengl
  + Improvements:
  - Make splash screen preference to allow it to be disabled
  - Update core app code to align with current anjuta
  + Bugs fixed:
  - Reintroduce track normalization
  - Allows the LOG path to contain spaces.
  + libgtkpod bugfixes:
  - Allow broadcast of string preferences
  - Provide some sensible sorting of tracks when added from files
    and directories
  - Ensure progress bar is updated when saving ipod database
  - Avoid possibility of symlinks, when adding files, hanging
    gtkpod
  - Display track conversion progress correctly
  - Fix for track volume control
  + Various plugin bugfixes.
- Add pkgconfig(clutter-gtk-1.0) BuildRequires for the new
  alternative coverart plugin.
- Drop gtkpod-gtk_box.patch: fixed upstream.
* Fri Dec  2 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Tue Aug  9 2011 dimstar@opensuse.org
- Update to 2.1.0:
  + Minor code fixes / build fixes compared to the beta.
- Rebase gtkpod-gtk_box.patch: Only part of the patch was merged.
- Drop gtkpod-gdk3.patch and gtkpod-g_const_return.patch: fixed
  upstream.
* Mon Aug  1 2011 dimstar@opensuse.org
- Update to version 2.1.0.beta:
  + Media player plugin fixes:
  - When the stop button is pressed, ensure that the play/pause
    button is reset accordinly.
  - Add some warning and debug information if the player fails to
    play.
  + Track plugin fixes:
  - Stop the Rating column from being expanded to a too long size
  - Align 2 checkboxes in the preferences to make them look a
    little neater
  - Populate the horizontal scrollbar checkbox with its value
  + Cover art display fixes for colors and updating
  + Stop volume property warning when media player loaded
  + Fixes cover art preference stretching.
- Add patches:
  + gtkpod-gdk3.patch: Fix detection of GSEAL enabled gdk version.
  + gtkpod-g_const_return.patch: No longer use G_CONST_RETURN.
  + gtkpod-gtk_box.patch: Stop using deprecated gtk_[hv]box_new.
  + gtkpod-glade.patch: Fix the glade files to no longer use
    deprecated GtkComboBoxEntry.
- Add gsettings schema handling macros to post/postun.
* Mon May 16 2011 dimstar@opensuse.org
- Update to version 2.0.1:
  + Only link plugins to their respective libraries rather than
    libgtkpod library.
  + Bugfixes:
  - Stop exporter plugin crashes by avoiding display of dialogs.
  - Stop unloading plugins when quitting. Avoids throwing a
    gobject exception.
  - Dispose directory paths when quitting.
  - Fix segfault if gstreamer plugins are not installed.
  - Allow compiling of m4a and mp4 plugins against older versions
    of libmp4v2.
  - Formatting strings correction in gtkpod_log_error.
  - Remove deprecated gtk code.
  - Final removal of glade dependencies but still need to depend
    on libxml2.
- do not export LDFLAGS="-Wl,--as-needed". It became the default.
* Mon Mar 21 2011 dimstar@opensuse.org
- Update to version 2.0.0.5631699:
  + UI completely reworked with anjuta as the windowing system.
  + Provide major features as plugins that can be added and removed
    depending upon user preference.
  + Replacement of glade with gtkbuilder (apparently incomplete)
  + Updated translations.
- Split out -devel package and libgtkpod1 as per SLPP.
- Add BuildRequires: fdupes, pkgconfig({libanjuta-1.0,gdl-1.0})
- Pass disable-static to configure and delete *.la in _libdir
- use make_install macro
- Link duplicate files in _datadir using fdupes.
- Rebase gtkpod-pref.patch: moved to libgtkpod and mountpoint
  default path is now correct by default.
* Sat Feb 12 2011 vuntz@opensuse.org
- Call relevant macros in %%post/%%postun:
  + %%desktop_database_post/postun because the package ships at
    least one desktop file.
  + %%icon_theme_cache_post/postun because the package ships themed
    icons.
- Pass %%{?no_lang_C} to %%find_lang so that english documentation
  can be packaged with the program, and not in the lang subpackage.
- Split lang subpackage.
* Wed Aug 11 2010 vuntz@opensuse.org
- Update to version 1.0.0:
  + Final release of gtkpod before the major UI refactorings with
    anjuta are incorporated.
  + Make dialogs transient with gtkpod window
  + Make the no extended database message clearer
  + Failure to read lyrics file no longer displays a warning dialog
    for each track. Instead it displays the error in the lyrics
    tab.
  + Track filter tends to display no results
  + Various deficiencies with audiobooks.
  + Memory leaks.
  + Updated translations.
- Remove unneeded gnutls-devel BuildRequires.
* Mon Mar 22 2010 vuntz@opensuse.org
- Remove unneeded BuildRequires: gnutls-devel,
  libgnomeprintui-devel, libgnomeui-devel, libwnck-devel,
  perl-XML-Parser
* Mon Mar 22 2010 dimstar@opensuse.org
- Update to version 0.99.16:
  + Volume control added to detail window for setting the volume of
    a track.
  + Migration from hal, which is now deprecated, to gio.
  + Support for using CMake as well as autotools
  + Code compatibility for compiling using Clang
  + BUGFIX: Crash when a cover art image is dragged and dropped.
  + BUGFIX: Freeze when changing from the photo window back to the
    playlist window.
  + BUGFIX: Numerous double frees and memory leaks.
  + Translations support.
- BuildRequire intltool.
* Wed Aug 26 2009 mls@suse.de
- make patch0 usage consistent
* Thu Jul 16 2009 dominique-obs@leuenberger.net
- update to version 0.99.14
  * Help system, still very preliminary
  * Video thumbnail generation
  * Lyrics may be viewed and edited via the Details window for a
    track. Only mp3 files are supported currently
  * Add a search bar, to quickly filter tracks
  * New application icon
  * Preferences dialog redesigned from the ground up for
    GNOME HIG compliance
  * Updated translations
  * Numerous UI cleanups
  * Support for chapter data
  * Use cairo for coverart display effects.
  - > dropped dependency to libgnomecanvas
  * Coverart display performance has been improved
  * Set track->lyrics_flag for mp4 files in addition to mp3 files
  * Use the Artist tag for the Artist and fall back to the Album
    Artist tag only when the former does not exist. For Album
    Artist, use the Album Artist tag, but only if the Artist tag
    does exist
  * The Photo "playlist" is a separate object in the Playlist view
  * Numerous memory leaks fixed
  * Many other bug fixes and cleanups.
- dropped gtkpod-non_static_decl.patch
- refactored gtkpod-pref.patch
* Mon Feb 11 2008 crrodriguez@suse.de
- fix ogg/vorbis support for real
* Sat Feb  9 2008 crrodriguez@suse.de
- fix missing flac , ogg and libcurl support
- only link libraries "as-needed"
* Thu Jan 17 2008 hvogel@suse.de
- update to version 0.99.12
  * Import and management of photographs on ipods
  * Better icon theme specification compliance.
  * Cover art preview window either displays an album cover
    to its full size or to a size consistent with the user's desktop
  * Download of Album Art from the net feature modified to the
    ability of dragging-and-dropping a .jpg image from a web browser.
  * New scripts for flac, ogg, mp3, m4a, wav conversion to mp3 and
    m4a
  * Fixed memory leaks in CoverArt Display and Details window
  * Translation Updates
* Thu Oct 11 2007 sbrabec@suse.cz
- Removed bogus dependency on mDNSResponder.
* Thu Sep 13 2007 hvogel@suse.de
- Fix missing fclose on music files [#310045]
* Wed Jul  4 2007 hvogel@suse.de
- Update to version 0.99.10
  * various bugfixes
  * translation updates
  * on-the-fly conversion of WAV, FLAC and OGG
  * editing of TV show metadata and track media type
  * Display/Download of Album Art
* Thu Apr 19 2007 pgajdos@suse.cz
- extend literal_comparsion.patch to avoid next new gcc warnings
* Tue Apr 17 2007 pgajdos@suse.cz
- fixed 'comparsion with string literal' [#231181]
- literal_comparsion.patch
* Fri Mar 30 2007 ssommer@suse.de
- add flex to BuildRequires
* Mon Feb  5 2007 ro@suse.de
- fix build with current libgpod
* Sun Jan  7 2007 ro@suse.de
- GNOME moved to /usr
* Mon Oct 23 2006 hvogel@suse.de
- update to version 0.99.8
  * Support of several iPods
  * Support for mobile phones supporting iTunes
  * Support for coverart has been improved
* Mon Jul 10 2006 mskibbe@suse.de
- update to version 0.99.4 which includes
  o BUGFIX: Options for exporting playlist files could not be
    changed.
  o BUGFIX: Fixed segfault when updating tracks or directories
    with artowrk present.
  o BUGFIX: Browse button for "Sync Notes Script" opened a
    directory browser instead of a file browser.
  o BUGFIX: Writing ID3v2.4 tags in UTF8 did not always
    work. Thanks to 't0c' for the patch.
  o BUGFIX: Context Menus for removing playlists from the iPod
    were not displayed. Thanks to 'rob/biffhero' for pointing this
    out.
- patch gtkpod-variable-mountpoint.patch is included in new version
* Mon Feb  6 2006 hvogel@suse.de
- make -m switch for variable mount point working again. Patch from
  Jorg Schuler.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Jan 13 2006 hvogel@suse.de
- Update to version 0.99.2
* Mon Aug 22 2005 hvogel@suse.de
- Mountpoint is /media/ipod now. Updated pref's patch
* Mon Jul 18 2005 hvogel@suse.de
- Update to version 0.94.0
- got rid of the symlink patch
* Mon Jun 27 2005 hvogel@suse.de
- Update to version 0.93.1
* Tue Apr 26 2005 hvogel@suse.de
- Update to version 0.88.2
- remove static declaration
* Fri Mar 18 2005 hvogel@suse.de
- Should now work with the shuffle -- forgot to change a
  version number in the iTunesDB file
* Fri Mar 11 2005 hvogel@suse.de
- add support for ipod shuffle (Update to Version 0.88)
* Thu Mar  3 2005 hvogel@suse.de
- This time really add the scripts for evolution
* Thu Mar  3 2005 hvogel@suse.de
- update to version 0.87.3 which includes:
  o Evolution Contacts/Calender/Tasks sync
  o drag and drop for other formats than mp3
  o fix an charset bug
  o ignore "the" and the like in sorting
  o use statvfs instead of df
  o Updated Swedish/Italian translations
* Mon Feb 14 2005 hvogel@suse.de
- adapt mountpoint to /media/iPod
* Tue Dec  7 2004 hvogel@suse.de
- prefs patch was missing the export filename setting. fixed
* Mon Nov 22 2004 hvogel@suse.de
- update to version 0.80.5
* Mon Jul 19 2004 hvogel@suse.de
- update to version 0.80-2
- remove gtk2.2 patch which slipped trough last time
* Mon Jul 12 2004 hvogel@suse.de
- Update to version 0.80
- add icon to the desktop file
* Sat Mar 13 2004 hvogel@suse.de
- patch mount point
- patch mp3 namings
* Thu Jan 29 2004 hvogel@suse.de
- bzip2 the source package
* Tue Jan 20 2004 hvogel@suse.de
- update to version 0.72
- needs libid3tag now instead of id3lib
* Mon Dec  1 2003 hvogel@suse.de
- update to version 0.70
* Thu Nov 13 2003 hvogel@suse.de
- dont build as root
* Mon Oct 13 2003 hvogel@suse.de
- update to version 0.60
* Fri Sep 19 2003 hvogel@suse.de
- fixed category
* Thu Sep  4 2003 hvogel@suse.de
- added Category
* Fri Aug  1 2003 hvogel@suse.de
- updated italian po translation
- moved to gnome prefix
* Thu Jul 31 2003 hvogel@suse.de
- created .desktop file
* Fri Jul 18 2003 hvogel@suse.de
- update to Version 0.52
* Mon Jun  2 2003 hvogel@suse.de
- Initial Package, Version 0.51
